==> fillets-ng-data-0.7.1.tar.gz: fillets-ng-data-0.7.1/script/viking1/dialogs_es.lua <==

dialogId("dr-m-tojesnad", "font_small", "This must be a Viking ship!")
dialogStr("Esta debe de ser una nave Vikinga!")


dialogId("dr-v-jiste", "font_big", "Sure, it`s a drakkar.")
dialogStr("Seguro, es un drakkar.")


dialogId("dr-m-musela", "font_small", "She must have sunk fast. The oarsmen are still in their places.")
dialogStr("Se debe de haber hundido rápido. Los remeros todavía están en sus lugares.")


dialogId("dr-v-mozna", "font_big", "Maybe they sank her on purpose. Warriors would always accompany their leader on his way to Valhalla.")
dialogStr("Quizás la hundieron a propósito. Los guerreros siempre acompañan a sus líderes en su camino al Valhalla.")


dialogId("dr-m-hruza", "font_small", "That's awful. They look like they're still alive.")
dialogStr("Que tremendo. Pareciera que ellos todavía estuvieran vivos.")


dialogId("d1-1-hudba0", "font_viking1", "The music is gone!")
dialogStr("¡La música se fué!")


dialogId("d1-1-hudba1", "font_viking1", "They stopped playing!")
dialogStr("¡Dejaron de tocar!")


dialogId("d1-1-hudba2", "font_viking1", "The music stopped again!")
dialogStr("¡La música se detuvo de nuevo!")


dialogId("d1-2-brb0", "font_viking2", "Oh, no!")
dialogStr("¡Oh, no!")


dialogId("d1-2-brb1", "font_viking2", "Again?")
dialogStr("¿De nuevo?")


dialogId("d1-2-brb2", "font_viking2", "Oh, not again!")
dialogStr("¡Oh, no de nuevo!")


dialogId("d1-3-brb0", "font_viking3", "What happened?")
dialogStr("¿Qué pasó?")


dialogId("d1-3-brb1", "font_viking3", "Again?")
dialogStr("¿De nuevo?")


dialogId("d1-3-brb2", "font_viking3", "Oh, no!")
dialogStr("¡Oh, no!")


dialogId("d1-4-brb0", "font_viking4", "The bloody music stopped!")
dialogStr("¡La maldita música se detuvo!")


dialogId("d1-4-brb1", "font_viking4", "What are they doing up there?")
dialogStr("¿Qué están haciendo ellos ahí arriba?")


dialogId("d1-4-brb2", "font_viking4", "How could it be?")
dialogStr("¿Cómo puede ser?")


dialogId("d1-5-nevadi0", "font_viking5", "Take it easy, boys. Solo for Olaf!")
dialogStr("Tómenlo con calma muchachos. ¡Un solo para Olafo!")


dialogId("d1-5-nevadi1", "font_viking5", "Never mind that, boys. We can sing ourself!")
dialogStr("No importa, muchachos. ¡Podemos cantar nosotros mismos!")


dialogId("d1-5-nevadi2", "font_viking5", "Never mind, boys. We can sing ourself, like in the old times!")
dialogStr("No importa muchachos. Podemos cantar nosotros mismos, ¡Como en los viejos tiempos!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/viking1/dialogs_es.lua <==

dialogId("dr-m-tojesnad", "font_small", "This must be a Viking ship!")
dialogStr("Esta debe de ser una nave Vikinga!")


dialogId("dr-v-jiste", "font_big", "Sure, it’s a drakkar.")
dialogStr("Seguro, es un drakkar.")


dialogId("dr-m-musela", "font_small", "She must have sunk fast. The oarsmen are still in their places.")
dialogStr("Se debe de haber hundido rápido. Los remeros todavía están en sus lugares.")


dialogId("dr-v-mozna", "font_big", "Maybe they sank her on purpose. Warriors would always accompany their leader on his way to Valhalla.")
dialogStr("Quizás la hundieron a propósito. Los guerreros siempre acompañan a sus líderes en su camino al Valhalla.")


dialogId("dr-m-hruza", "font_small", "That's awful. They look like they're still alive.")
dialogStr("Que tremendo. Pareciera que ellos todavía estuvieran vivos.")


dialogId("d1-1-hudba0", "font_viking1", "The music is gone!")
dialogStr("¡La música se fué!")


dialogId("d1-1-hudba1", "font_viking1", "They stopped playing!")
dialogStr("¡Dejaron de tocar!")


dialogId("d1-1-hudba2", "font_viking1", "The music stopped again!")
dialogStr("¡La música se detuvo de nuevo!")


dialogId("d1-2-brb0", "font_viking2", "Oh, no!")
dialogStr("¡Oh, no!")


dialogId("d1-2-brb1", "font_viking2", "Again?")
dialogStr("¿De nuevo?")


dialogId("d1-2-brb2", "font_viking2", "Oh, not again!")
dialogStr("¡Oh, no de nuevo!")


dialogId("d1-3-brb0", "font_viking3", "What happened?")
dialogStr("¿Qué pasó?")


dialogId("d1-3-brb1", "font_viking3", "Again?")
dialogStr("¿De nuevo?")


dialogId("d1-3-brb2", "font_viking3", "Oh, no!")
dialogStr("¡Oh, no!")


dialogId("d1-4-brb0", "font_viking4", "The bloody music stopped!")
dialogStr("¡La maldita música se detuvo!")


dialogId("d1-4-brb1", "font_viking4", "What are they doing up there?")
dialogStr("¿Qué están haciendo ellos ahí arriba?")


dialogId("d1-4-brb2", "font_viking4", "How could it be?")
dialogStr("¿Cómo puede ser?")


dialogId("d1-5-nevadi0", "font_viking5", "Take it easy, boys. Solo for Olaf!")
dialogStr("Tómenlo con calma muchachos. ¡Un solo para Olafo!")


dialogId("d1-5-nevadi1", "font_viking5", "Never mind that, boys. We can sing ourself!")
dialogStr("No importa, muchachos. ¡Podemos cantar nosotros mismos!")


dialogId("d1-5-nevadi2", "font_viking5", "Never mind, boys. We can sing ourself, like in the old times!")
dialogStr("No importa muchachos. Podemos cantar nosotros mismos, ¡Como en los viejos tiempos!")
